@@ -2,10 +2,9 @@
 Models for input parameters of the School APIs.
 """
 
-
 from typing import Optional
 
-from pydantic import root_validator
+from pydantic.v1 import root_validator
 
 from . import BaseRequestModel
 
